@@ -397,7 +397,7 @@ def dev(
     new: bool = typer.Option(
         False,
         "--new",
-        help="Show Cursor installation link for new server setup",
+        help="Create a new dev trace on hud.ai (opens in browser)",
     ),
 ) -> None:
     """🔥 Development mode - run MCP server with hot-reload.
@@ -416,6 +416,7 @@ def dev(
 
     Examples:
         hud dev                      # Auto-detect in current directory
+        hud dev --new                # Create live dev trace on hud.ai
         hud dev controller           # Run specific module
         hud dev --inspector          # Launch MCP Inspector
         hud dev --interactive        # Launch interactive testing mode
@@ -439,7 +440,7 @@ def dev(
         watch,
         docker=docker,
         docker_args=docker_args,
-        new=new,
+        new_trace=new,
     )
 
 
